@@ -199,8 +199,6 @@ static void
 _create_slide2answer_window(Slide2AnswerStatusPlugin* status_plugin)
 {
   status_plugin->priv->call_window = hildon_window_new();//gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  hildon_gtk_window_set_portrait_flags(GTK_WINDOW(status_plugin->priv->call_window),
-				       HILDON_PORTRAIT_MODE_SUPPORT);
   /*
   GdkPixbuf* pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
 					       "general_default_avatar",
@@ -224,6 +222,8 @@ _create_slide2answer_window(Slide2AnswerStatusPlugin* status_plugin)
 		      "bidirectional-slider-horizontal");
   gtk_range_set_range(GTK_RANGE(status_plugin->priv->call_window_slider), -1.0, 1.0);              
   gtk_range_set_value(GTK_RANGE(status_plugin->priv->call_window_slider), 0.0);
+  gtk_widget_set_name(status_plugin->priv->call_window_slider,
+		      "sui-tklock-slider");
   
   GtkWidget* accept_button = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT,
 					       HILDON_BUTTON_ARRANGEMENT_VERTICAL);
@@ -262,6 +262,34 @@ _create_slide2answer_window(Slide2AnswerStatusPlugin* status_plugin)
   gtk_widget_show_all(content);
 }
 
+static void
+_set_call_ui_orientation_mode(Slide2AnswerStatusPlugin* status_plugin)
+{
+  GKeyFile *keyFile;
+  keyFile = g_key_file_new();
+  const gchar* fileName = "/home/user/.osso/call-ui.ini";
+  if(g_key_file_load_from_file(keyFile, fileName, G_KEY_FILE_KEEP_COMMENTS, NULL))
+  {
+    int mode = g_key_file_get_integer(keyFile, "rotation", "orientation", NULL);
+    if(mode == 0)
+    {
+      hildon_gtk_window_set_portrait_flags(GTK_WINDOW(status_plugin->priv->call_window),
+					   HILDON_PORTRAIT_MODE_REQUEST);
+    }
+    else if(mode == 1)
+    {
+      hildon_gtk_window_set_portrait_flags(GTK_WINDOW(status_plugin->priv->call_window),
+					   0);
+    }
+    else 
+    {
+      hildon_gtk_window_set_portrait_flags(GTK_WINDOW(status_plugin->priv->call_window),
+					   HILDON_PORTRAIT_MODE_SUPPORT);
+    }
+  }
+  g_key_file_free(keyFile);
+}
+
 static void
 _show_slide2answer_window(Slide2AnswerStatusPlugin* plugin)
 {
@@ -284,6 +312,8 @@ _show_slide2answer_window(Slide2AnswerStatusPlugin* plugin)
     gtk_range_set_value(GTK_RANGE(plugin->priv->call_window_slider), 0.0);
     gtk_widget_show_all(GTK_WIDGET(plugin->priv->call_window));
   }
+
+  _set_call_ui_orientation_mode(plugin);
 }
 
 static void
